@@ -1,10 +1,10 @@
-#' @importFrom stats deviance df.residual fitted rnorm runif
+#' @importFrom stats fitted rnorm runif
 #' @keywords internal
 simulate.nls <- function (object, nsim = 1, seed = NULL, ...) {
   
   # Initialize random number generator
   if (!exists(".Random.seed", envir = .GlobalEnv, inherits = FALSE)) 
-    runif(1)
+    stats::runif(1)
   if (is.null(seed)) 
     RNGstate <- get(".Random.seed", envir = .GlobalEnv)
   else {
@@ -15,15 +15,15 @@ simulate.nls <- function (object, nsim = 1, seed = NULL, ...) {
   }
   
   # Simulate new response values
-  ftd <- fitted(object)  # fitted values
+  ftd <- stats::fitted(object)  # fitted values
   nm <- names(ftd)  # row names
   n <- length(ftd)  # number of observations
   ntot <- n * nsim  # number of observations to simulate
-  vars <- deviance(object) / df.residual(object)  # residual variance
+  vars <- stats::deviance(object) / stats::df.residual(object)  # residual variance
   if (!is.null(object$weights)) {
     vars <- vars/object$weights
   }
-  val <- ftd + rnorm(ntot, sd = sqrt(vars))  # simulated response values
+  val <- ftd + stats::rnorm(ntot, sd = sqrt(vars))  # simulated response values
   
   # Return simulated response values with appropriate dimension, class, etc.
   if (!is.list(val)) {
