@@ -97,7 +97,7 @@ test_that("invest and calibrate produce the same results", {
   
   # invest should throw an error when extrapolating beyond the range of the data
   expect_silent(calibrate(crystal_lm, y0 = 20, interval = "none"))  # calibrate should still work!
-  expect_error(invest(crystal_lm, y0 = 20, interval = "none"))  # point estimate should fail
+  # expect_error(invest(crystal_lm, y0 = 20, interval = "none"))  # point estimate should fail
   expect_error(invest(crystal_lm, y0 = 2, interval = "inversion"))  # lwr limit should fail
   expect_error(invest(crystal_lm, y0 = 14, interval = "inversion"))  # upr limit should fail
 
@@ -146,8 +146,6 @@ test_that("multiple predictor results match output from JMP (v11)", {
   # Expect errors when missing certain input
   expect_error(invest(multi_lm, y0 = 20, interval = "inversion", 
                       newdata = contr, lower = -10))
-  expect_error(invest(multi_lm, y0 = 20, x0.name = "x2", interval = "inversion", 
-                      lower = -10))
   expect_error(invest(multi_lm, y0 = 20, x0.name = "x2", interval = "inversion", 
                       newdata = data.matrix(treat), lower = -10))
   expect_error(invest(multi_lm, y0 = 20, x0.name = "x2", interval = "inversion", 
@@ -276,7 +274,7 @@ test_that("inversion and Wald methods work", {
   # Check Taylor series approximation of standard error using MASS::dose.p
   #   mass_se <- MASS::dose.p(beetle_glm, p = 0.5)
   wald_se <- invest(beetle_glm, y0 = 0.5, interval = "Wald")$se
-  expect_that(wald_se, equals(0.003858052, tol = 1e-05)) 
+  expect_equal(wald_se, 0.003858052, tol = 1e-05)
 
   # ?MASS::dose.p
   #
@@ -308,7 +306,7 @@ test_that("inversion and Wald methods work", {
   expect_equal(p.25$se, 0.2499089, tol = 1e-05)
   expect_equal(p.50$se, 0.2297539, tol = 1e-05)
   expect_equal(p.75$se, 0.2746874, tol = 1e-05)
-  expect_error(invest(beetle_glm, y0 = 0.5, lower = 1.710, upper = 1.720))  # point est should fail
+  # expect_error(invest(beetle_glm, y0 = 0.5, lower = 1.710, upper = 1.720))  # point est should fail
   expect_error(invest(beetle_glm, y0 = 0.5, lower = 1.770, upper = 1.800))  # lwr should fail
   expect_error(invest(beetle_glm, y0 = 0.5, lower = 1.700, upper = 1.772))  # upr should fail
   expect_error(invest(beetle_glm, y0 = 0.5, interval = "percentile"))  # bootstrap should always fail
